@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-app.h,v 1.2 2005/12/12 17:27:55 pborelli Exp $
+ * $Id: gedit-app.h 5666 2007-06-29 19:52:25Z sfre $
  */
 
 #ifndef __GEDIT_APP_H__
@@ -42,7 +42,6 @@ G_BEGIN_DECLS
  */
 #define GEDIT_TYPE_APP              (gedit_app_get_type())
 #define GEDIT_APP(obj)              (G_TYPE_CHECK_INSTANCE_CAST((obj), GEDIT_TYPE_APP, GeditApp))
-#define GEDIT_APP_CONST(obj)        (G_TYPE_CHECK_INSTANCE_CAST((obj), GEDIT_TYPE_APP, GeditApp const))
 #define GEDIT_APP_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST((klass), GEDIT_TYPE_APP, GeditAppClass))
 #define GEDIT_IS_APP(obj)           (G_TYPE_CHECK_INSTANCE_TYPE((obj), GEDIT_TYPE_APP))
 #define GEDIT_IS_APP_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), GEDIT_TYPE_APP))
@@ -74,6 +73,18 @@ struct _GeditAppClass
 	GObjectClass parent_class;
 };
 
+/*
+ * Lockdown mask definition
+ */
+typedef enum
+{
+	GEDIT_LOCKDOWN_COMMAND_LINE	= 1 << 0,
+	GEDIT_LOCKDOWN_PRINTING		= 1 << 1,
+	GEDIT_LOCKDOWN_PRINT_SETUP	= 1 << 2,
+	GEDIT_LOCKDOWN_SAVE_TO_DISK	= 1 << 3,
+	GEDIT_LOCKDOWN_ALL		= 0xF
+} GeditLockdownMask;
+
 /*
  * Public methods
  */
@@ -81,7 +92,8 @@ GType 		 gedit_app_get_type 			(void) G_GNUC_CONST;
 
 GeditApp 	*gedit_app_get_default			(void);
 
-GeditWindow	*gedit_app_create_window		(GeditApp *app);
+GeditWindow	*gedit_app_create_window		(GeditApp  *app,
+							 GdkScreen *screen);
 
 const GList	*gedit_app_get_windows			(GeditApp *app);
 GeditWindow	*gedit_app_get_active_window		(GeditApp *app);
@@ -92,13 +104,29 @@ GList		*gedit_app_get_documents		(GeditApp *app);
 /* Returns a newly allocated list with all the views */
 GList		*gedit_app_get_views			(GeditApp *app);
 
+/* Lockdown state */
+GeditLockdownMask gedit_app_get_lockdown		(GeditApp *app);
+
 /*
  * Non exported functions
  */
 GeditWindow	*_gedit_app_restore_window		(GeditApp    *app,
 							 const gchar *role);
-GeditWindow	*_gedit_app_get_window_in_workspace	(GeditApp *app,
-							 gint      workspace);
+GeditWindow	*_gedit_app_get_window_in_workspace	(GeditApp  *app,
+							 GdkScreen *screen,
+							 gint       workspace);
+void		 _gedit_app_set_lockdown		(GeditApp          *app,
+							 GeditLockdownMask  lockdown);
+void		 _gedit_app_set_lockdown_bit		(GeditApp          *app,
+							 GeditLockdownMask  bit,
+							 gboolean           value);
+/*
+ * This one is a gedit-window function, but we declare it here to avoid
+ * #include headaches since it needs the GeditLockdownMask declaration.
+ */
+void		 _gedit_window_set_lockdown		(GeditWindow         *window,
+							 GeditLockdownMask    lockdown);
+
 
 G_END_DECLS
 
