@@ -30,9 +30,9 @@
 #ifndef __GEDIT_PREFS_MANAGER_H__
 #define __GEDIT_PREFS_MANAGER_H__
 
-#include <gdk/gdkcolor.h>
 #include <gtk/gtkenums.h>
 #include <glib/gslist.h>
+#include <gtksourceview/gtksourceview.h>
 #include "gedit-app.h"
 
 #define GEDIT_BASE_KEY	"/apps/gedit-2"
@@ -43,13 +43,7 @@
 #define GPM_FONT_DIR			GPM_PREFS_DIR "/editor/font"
 #define GPM_USE_DEFAULT_FONT		GPM_FONT_DIR "/use_default_font"
 #define GPM_EDITOR_FONT			GPM_FONT_DIR "/editor_font"
-
-#define GPM_COLORS_DIR			GPM_PREFS_DIR  "/editor/colors"
-#define GPM_USE_DEFAULT_COLORS		GPM_COLORS_DIR "/use_default_colors"
-#define GPM_BACKGROUND_COLOR		GPM_COLORS_DIR "/background_color"
-#define GPM_TEXT_COLOR			GPM_COLORS_DIR "/text_color"
-#define GPM_SELECTED_TEXT_COLOR		GPM_COLORS_DIR "/selected_text_color"
-#define GPM_SELECTION_COLOR		GPM_COLORS_DIR "/selection_color"
+#define GPM_SYSTEM_FONT			"/desktop/gnome/interface/monospace_font_name"
 
 #define GPM_SAVE_DIR			GPM_PREFS_DIR  "/editor/save"
 #define GPM_CREATE_BACKUP_COPY  	GPM_SAVE_DIR "/create_backup_copy"
@@ -84,12 +78,18 @@
 #define GPM_DISPLAY_RIGHT_MARGIN	GPM_RIGHT_MARGIN_DIR "/display_right_margin"
 #define GPM_RIGHT_MARGIN_POSITION	GPM_RIGHT_MARGIN_DIR "/right_margin_position"
 
+#define GPM_SMART_HOME_END_DIR		GPM_PREFS_DIR "/editor/smart_home_end"
+#define GPM_SMART_HOME_END		GPM_SMART_HOME_END_DIR "/smart_home_end"
+
 #define GPM_CURSOR_POSITION_DIR		GPM_PREFS_DIR  "/editor/cursor_position"
 #define GPM_RESTORE_CURSOR_POSITION	GPM_CURSOR_POSITION_DIR "/restore_cursor_position"
 
 #define GPM_SEARCH_HIGHLIGHTING_DIR	GPM_PREFS_DIR "/editor/search_highlighting"
 #define GPM_SEARCH_HIGHLIGHTING_ENABLE	GPM_SEARCH_HIGHLIGHTING_DIR "/enable"
 
+#define GPM_SOURCE_STYLE_DIR		GPM_PREFS_DIR "/editor/colors"
+#define GPM_SOURCE_STYLE_SCHEME		GPM_SOURCE_STYLE_DIR "/scheme"
+
 /* UI */
 #define GPM_TOOLBAR_DIR			GPM_PREFS_DIR "/ui/toolbar"
 #define GPM_TOOLBAR_VISIBLE	 	GPM_TOOLBAR_DIR "/toolbar_visible"
@@ -122,13 +122,6 @@
 #define GPM_PRINT_FONT_NUMBERS		GPM_PRINT_FONT_DIR "/print_font_numbers"
 #define GPM_PRINT_FONT_NUMBERS_PANGO	GPM_PRINT_FONT_DIR "/print_font_numbers_pango"
 
-#define GPM_WINDOW_DIR			"/gedit-2/window"
-#define GPM_WINDOW_STATE		GPM_WINDOW_DIR "/state"
-#define GPM_WINDOW_WIDTH		GPM_WINDOW_DIR "/width"
-#define GPM_WINDOW_HEIGHT		GPM_WINDOW_DIR "/height"
-#define GPM_SIDE_PANEL_SIZE		GPM_WINDOW_DIR "/side_panel_size"
-#define GPM_BOTTOM_PANEL_SIZE		GPM_WINDOW_DIR "/bottom_panel_size"
-
 /* Encodings */
 #define GPM_ENCODINGS_DIR		GPM_PREFS_DIR "/encodings"
 #define GPM_AUTO_DETECTED_ENCODINGS	GPM_ENCODINGS_DIR "/auto_detected"
@@ -150,14 +143,9 @@
 
 /* Fallback default values. Keep in sync with gedit.schemas */
 
-#define GPM_DEFAULT_USE_DEFAULT_FONT 	0 /* FALSE */
+#define GPM_DEFAULT_USE_DEFAULT_FONT 	1 /* TRUE */
 #define GPM_DEFAULT_EDITOR_FONT 	(const gchar*) "Monospace 12"
-
-#define GPM_DEFAULT_USE_DEFAULT_COLORS 	1 /* TRUE */
-#define GPM_DEFAULT_BACKGROUND_COLOR	(const gchar*) "#ffffffffffff"
-#define GPM_DEFAULT_TEXT_COLOR		(const gchar*) "#000000000000"
-#define GPM_DEFAULT_SELECTED_TEXT_COLOR	(const gchar*) "#ffffffffffff"
-#define GPM_DEFAULT_SELECTION_COLOR	(const gchar*) "#000000009c9c"
+#define GPM_DEFAULT_SYSTEM_FONT 	(const gchar*) "Monospace 10"
 
 #define GPM_DEFAULT_CREATE_BACKUP_COPY	1 /* TRUE */
 #define GPM_DEFAULT_BACKUP_COPY_EXTENSION (const gchar*) "~"
@@ -197,20 +185,6 @@
 
 #define GPM_DEFAULT_MAX_RECENTS		5
 
-#define GPM_DEFAULT_WINDOW_STATE	0
-#define GPM_DEFAULT_WINDOW_WIDTH	650
-#define GPM_DEFAULT_WINDOW_HEIGHT	500
-
-#define GPM_DEFAULT_WINDOW_STATE_STR	"0"
-#define GPM_DEFAULT_WINDOW_WIDTH_STR	"650"
-#define GPM_DEFAULT_WINDOW_HEIGHT_STR	"500"
-
-#define GPM_DEFAULT_SIDE_PANEL_SIZE	200
-#define GPM_DEFAULT_BOTTOM_PANEL_SIZE 	140
-
-#define GPM_DEFAULT_SIDE_PANEL_SIZE_STR   "200"
-#define GPM_DEFAULT_BOTTOM_PANEL_SIZE_STR "140"
-
 #define GPM_DEFAULT_HIGHLIGHT_CURRENT_LINE  1 /* TRUE */
 
 #define GPM_DEFAULT_BRACKET_MATCHING	  0 /* FALSE */
@@ -218,6 +192,8 @@
 #define GPM_DEFAULT_DISPLAY_RIGHT_MARGIN  0 /* FALSE */
 #define GPM_DEFAULT_RIGHT_MARGIN_POSITION 80
 
+#define GPM_DEFAULT_SMART_HOME_END	"AFTER"
+
 #define GPM_DEFAULT_SYNTAX_HL_ENABLE	1 /* TRUE */
 
 #define GPM_DEFAULT_WRITABLE_VFS_SCHEMES {"ssh", "sftp", "smb", "dav", "davs", NULL}
@@ -226,6 +202,8 @@
 
 #define GPM_DEFAULT_SEARCH_HIGHLIGHTING_ENABLE 1 /* TRUE */
 
+#define GPM_DEFAULT_SOURCE_STYLE_SCHEME "classic"
+
 typedef enum {
 	GEDIT_TOOLBAR_SYSTEM = 0,
 	GEDIT_TOOLBAR_ICONS,
@@ -253,30 +231,8 @@ gchar 			*gedit_prefs_manager_get_editor_font		(void);
 void			 gedit_prefs_manager_set_editor_font 		(const gchar *font);
 gboolean		 gedit_prefs_manager_editor_font_can_set	(void);
 
-/* Use default colors */
-gboolean 		 gedit_prefs_manager_get_use_default_colors 	(void);
-void			 gedit_prefs_manager_set_use_default_colors 	(gboolean udc);
-gboolean		 gedit_prefs_manager_use_default_colors_can_set	(void);
-
-/* Background color */	
-GdkColor		 gedit_prefs_manager_get_background_color	(void);
-void 			 gedit_prefs_manager_set_background_color	(GdkColor color);
-gboolean		 gedit_prefs_manager_background_color_can_set	(void);
-
-/* Text color */	
-GdkColor		 gedit_prefs_manager_get_text_color		(void);
-void 			 gedit_prefs_manager_set_text_color		(GdkColor color);
-gboolean		 gedit_prefs_manager_text_color_can_set		(void);
-
-/* Selection color */	
-GdkColor		 gedit_prefs_manager_get_selection_color	(void);
-void 			 gedit_prefs_manager_set_selection_color	(GdkColor color);
-gboolean		 gedit_prefs_manager_selection_color_can_set	(void);
-
-/* Selected text color */	
-GdkColor		 gedit_prefs_manager_get_selected_text_color	(void);
-void 			 gedit_prefs_manager_set_selected_text_color	(GdkColor color);
-gboolean		 gedit_prefs_manager_selected_text_color_can_set(void);
+/* System font */
+gchar 			*gedit_prefs_manager_get_system_font		(void);
 
 /* Create backup copy */
 gboolean		 gedit_prefs_manager_get_create_backup_copy	(void);
@@ -421,6 +377,12 @@ gint		 	 gedit_prefs_manager_get_right_margin_position	(void);
 void 			 gedit_prefs_manager_set_right_margin_position	(gint rmp);
 gboolean		 gedit_prefs_manager_right_margin_position_can_set (void);
 
+/* Smart home end */
+GtkSourceSmartHomeEndType
+		 	 gedit_prefs_manager_get_smart_home_end		(void);
+void 			 gedit_prefs_manager_set_smart_home_end		(GtkSourceSmartHomeEndType  smart_he);
+gboolean		 gedit_prefs_manager_smart_home_end_can_set	(void);
+
 /* Enable syntax highlighting */
 gboolean 		 gedit_prefs_manager_get_enable_syntax_highlighting (void);
 void			 gedit_prefs_manager_set_enable_syntax_highlighting (gboolean esh);
@@ -437,6 +399,11 @@ gboolean 		 gedit_prefs_manager_get_enable_search_highlighting (void);
 void			 gedit_prefs_manager_set_enable_search_highlighting (gboolean esh);
 gboolean		 gedit_prefs_manager_enable_search_highlighting_can_set (void);
 
+/* Style scheme */
+gchar			*gedit_prefs_manager_get_source_style_scheme	(void);
+void			 gedit_prefs_manager_set_source_style_scheme	(const gchar *scheme);
+gboolean		 gedit_prefs_manager_source_style_scheme_can_set(void);
+
 /* Global lockdown */
 GeditLockdownMask	 gedit_prefs_manager_get_lockdown			(void);
 
