@@ -26,14 +26,14 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-print.h 4429 2005-12-12 17:28:04Z pborelli $
+ * $Id: gedit-print.h 5666 2007-06-29 19:52:25Z sfre $
  */
 
 #ifndef __GEDIT_PRINT_H__
 #define __GEDIT_PRINT_H__
 
 #include <gedit/gedit-document.h>
-#include <gtksourceview/gtksourceprintjob.h>
+#include <gedit/gtksourceprintjob.h>
 #include <libgnomeprintui/gnome-print-dialog.h>
 
 G_BEGIN_DECLS
@@ -43,7 +43,6 @@ G_BEGIN_DECLS
  */
 #define GEDIT_TYPE_PRINT_JOB              (gedit_print_job_get_type())
 #define GEDIT_PRINT_JOB(obj)              (G_TYPE_CHECK_INSTANCE_CAST((obj), GEDIT_TYPE_PRINT_JOB, GeditPrintJob))
-#define GEDIT_PRINT_JOB_CONST(obj)        (G_TYPE_CHECK_INSTANCE_CAST((obj), GEDIT_TYPE_PRINT_JOB, GeditPrintJob const))
 #define GEDIT_PRINT_JOB_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST((klass), GEDIT_TYPE_PRINT_JOB, GeditPrintJobClass))
 #define GEDIT_IS_PRINT_JOB(obj)           (G_TYPE_CHECK_INSTANCE_TYPE((obj), GEDIT_TYPE_PRINT_JOB))
 #define GEDIT_IS_PRINT_JOB_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), GEDIT_TYPE_PRINT_JOB))
