@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit.c 5369 2006-12-17 15:41:19Z pborelli $
+ * $Id: gedit.c 5693 2007-07-07 10:17:38Z pborelli $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -70,7 +70,7 @@ static GSList *file_list = NULL;
 static const GOptionEntry options [] =
 {
 	{ "encoding", '\0', 0, G_OPTION_ARG_STRING, &encoding_charset,
-	  N_("Set the character encoding to be used to open the files listed on the command line"), "ENCODING" /* When out of string freeze, use N_("ENCODING") */ },
+	  N_("Set the character encoding to be used to open the files listed on the command line"), N_("ENCODING")},
 
 	{ "new-window", '\0', 0, G_OPTION_ARG_NONE, &new_window_option,
 	  N_("Create a new toplevel window in an existing instance of gedit"), NULL },
