@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gedit-spell-plugin.c 5335 2006-12-04 00:31:27Z paolo $
+ * $Id: gedit-spell-plugin.c 5880 2007-09-05 18:39:38Z jwendell $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -68,7 +68,7 @@ static const GtkActionEntry action_entries[] =
 	{ "CheckSpell",
 	  GTK_STOCK_SPELL_CHECK,
 	  N_("_Check Spelling"),
-	  "F7",
+	  "<shift>F7",
 	  N_("Check the current document for incorrect spelling"),
 	  G_CALLBACK (spell_cb)
 	},
@@ -658,12 +658,32 @@ add_word_cb (GeditSpellCheckerDialog *dlg,
 	ignore_cb (dlg, word, view);
 }
 
+static void
+language_dialog_response (GtkDialog         *dlg,
+			  gint               res_id,
+			  GeditSpellChecker *spell)
+{
+	if (res_id == GTK_RESPONSE_OK)
+	{
+		const GeditSpellCheckerLanguage *lang;
+
+		lang = gedit_spell_language_get_selected_language (GEDIT_SPELL_LANGUAGE_DIALOG (dlg));
+		if (lang != NULL)
+			gedit_spell_checker_set_language (spell, lang);
+	}
+
+	gtk_widget_destroy (GTK_WIDGET (dlg));
+}
+
 static void
 set_language_cb (GtkAction   *action,
 		 GeditWindow *window)
 {
 	GeditDocument *doc;
 	GeditSpellChecker *spell;
+	const GeditSpellCheckerLanguage *lang;
+	GtkWidget *dlg;
+	GtkWindowGroup *wg;
 
 	gedit_debug (DEBUG_PLUGINS);
 
@@ -673,7 +693,22 @@ set_language_cb (GtkAction   *action,
 	spell = get_spell_checker_from_document (doc);
 	g_return_if_fail (spell != NULL);
 
-	gedit_spell_language_dialog_run (spell, GTK_WINDOW (window));
+	lang = gedit_spell_checker_get_language (spell);
+
+	dlg = gedit_spell_language_dialog_new (GTK_WINDOW (window), lang);
+
+	wg = gedit_window_get_group (window);
+
+	gtk_window_group_add_window (wg, GTK_WINDOW (dlg));
+
+	gtk_window_set_modal (GTK_WINDOW (dlg), TRUE);
+
+	g_signal_connect (dlg,
+			  "response",
+			  G_CALLBACK (language_dialog_response),
+			  spell);
+
+	gtk_widget_show (dlg);
 }
 
 static void
